documentFactory.ComponentDocumentStream

|  | ## Cheshire3 Object Model: Class ComponentDocumentStream

Module documentFactory :: Class ComponentDocumentStream

## Class ComponentDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
                        ComponentDocumentStream

Instance Methods

__init__(self, session, stream, format, schema=None, codec=None, factory=None)
open_stream(self, stream)
find_documents(self, session, cache=0)
Inherited from `BaseDocumentStream`: `fetch_document`

Class Variables

sources |
Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### __init__(self, session, stream, format, schema=None, codec=None, factory=None) (Constructor) | source code
Overrides: BaseDocumentStream.__init__

### open_stream(self, stream) | source code
Overrides: BaseDocumentStream.open_stream

### find_documents(self, session, cache=0) | source code

Class Variable Details

    ### sources Value:
        []